.. :changelog:

History
-------

0.1.5 (2013-03-14)
+++++++++++++++++++
- Who would've guessed, changing requests to be versionless has indeed bit me in the ass.

0.1.3 (2012-08-26)
+++++++++++++++++++
- changed requests' installed_requires to be versionless (this will probably never bite me in the ass, nope, not at all)
- first working version successfully published to PyPI

0.1.2 (2012-08-26)
+++++++++++++++++++
- removed import from setup.py and manually added data to prevent importing requests library when doing the setup

0.1.1 (2012-08-26)
+++++++++++++++++++
- added newlines to LICENSE.txt

0.1.0 (2012-08-20)
+++++++++++++++++++
- Initial release.
